@@ -1,59 +1,58 @@
 -- =======================================================================
---                                 Player 1                                 
+--                                 Player 1
 -- =======================================================================
 p1:forbid_buildings("all")
 
-hq = p1:place_building("headquarters_shipwreck",
+hq = p1:place_building("empire_headquarters_shipwreck",
    wl.Game().map:get_field(6, 62), false, true)
-hq:set_wares{
-   helm = 4,
-   wood_lance = 5,
-   axe = 6,
-   bakingtray = 2,
+hq:set_wares {
    basket = 1,
-   bread = 8,
+   empire_bread = 8,
+   bread_paddle = 2,
    cloth = 5,
    coal = 12,
+   felling_ax = 6,
    fire_tongs = 2,
    fish = 6,
    fishing_rod = 2,
    flour = 4,
    gold = 4,
+   granite = 40,
    grape = 4,
    hammer = 12,
+   armor_helmet = 4,
    hunting_spear = 2,
    iron = 12,
-   ironore = 5,
+   iron_ore = 5,
    kitchen_tools = 4,
+   log = 30,
    marble = 25,
-   marblecolumn = 6,
+   marble_column = 6,
    meal = 4,
    meat = 6,
    pick = 14,
+   planks = 45,
    ration = 12,
    saw = 3,
    scythe = 5,
    shovel = 6,
-   stone = 40,
-   trunk = 30,
+   spear_wooden = 5,
    water = 12,
    wheat = 4,
    wine = 8,
-   wood = 45,
    wool = 2,
 }
-hq:set_workers{
-   armoursmith = 1,
-   brewer = 1,
-   builder = 10,
-   burner = 1,
-   carrier = 40,
-   geologist = 4,
-   lumberjack = 3,
-   miner = 4,
-   stonemason = 2,
-   toolsmith = 2,
-   weaponsmith = 1,
+hq:set_workers {
+   empire_armorsmith = 1,
+   empire_brewer = 1,
+   empire_builder = 10,
+   empire_carrier = 40,
+   empire_charcoal_burner = 1,
+   empire_geologist = 4,
+   empire_lumberjack = 3,
+   empire_miner = 4,
+   empire_stonemason = 2,
+   empire_toolsmith = 2,
+   empire_weaponsmith = 1,
 }
 hq:set_soldiers({0,0,0,0}, 45)
-
