@@ -33,7 +33,7 @@ tribes:new_productionsite_type {
    },
 
    aihints = {
-      prohibited_till = 600
+      prohibited_till = 540
    },
 
    working_positions = {
@@ -55,7 +55,7 @@ tribes:new_productionsite_type {
             "sleep=5000",
             "return=skipped unless economy needs flour",
             "consume=wheat",
-            "play_sound=sound/mill mill_turning 240",
+            "playsound=sound/mill mill_turning 240",
             "animate=working 10000",
             "produce=flour"
          }
