@@ -5,8 +5,9 @@ tribes:new_immovable_type {
    name = "grapevine_tiny",
    -- TRANSLATORS: This is an immovable name used in lists of immovables
    descname = pgettext("immovable", "Grapevine (tiny)"),
+   helptext_script = dirname .. "helptexts.lua",
    size = "medium",
-   attributes = { "field" },
+   attributes = { "field", "seed_grapes" },
    programs = {
       program = {
          "animate=idle 22000",
