@@ -1,17 +1,19 @@
 dirname = path.dirname(__file__)
 
 tribes:new_ware_type {
-   msgctxt = "barbarians_ware",
+   msgctxt = "ware",
    name = "helmet",
    -- TRANSLATORS: This is a ware name used in lists of wares
-   descname = pgettext("barbarians_ware", "Helmet"),
+   descname = pgettext("ware", "Helmet"),
    helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    default_target_quantity = {
-      barbarians = 1
+      barbarians = 1,
+      frisians = 2
    },
    preciousness = {
-      barbarians = 1
+      barbarians = 1,
+      frisians = 3
    },
 
    animations = {
