@@ -6,8 +6,8 @@ animations = {
       hotspot = { 2, 22 }
    }
 }
-add_worker_animations(animations, "walk", dirname, "walk", {6, 23}, 10)
-add_worker_animations(animations, "walkload", dirname, "walkload", {9, 22}, 10)
+add_walking_animations(animations, "walk", dirname, "walk", {6, 23}, 10)
+add_walking_animations(animations, "walkload", dirname, "walkload", {9, 22}, 10)
 
 
 tribes:new_worker_type {
