@@ -11,8 +11,8 @@ animations = {
       fps = 10
    }
 }
-add_worker_animations(animations, "walk", dirname, "walk", {16, 31}, 10)
-add_worker_animations(animations, "walkload", dirname, "walkload", {13, 29}, 10)
+add_walking_animations(animations, "walk", dirname, "walk", {16, 31}, 10)
+add_walking_animations(animations, "walkload", dirname, "walkload", {13, 29}, 10)
 
 
 tribes:new_worker_type {
@@ -31,13 +31,14 @@ tribes:new_worker_type {
 
    programs = {
       harvest = {
-         "findobject attrib:tree radius:10",
-         "walk object",
-         "play_sound sound/sawmill sawmill 230",
-         "animation sawing 10000",
-         "object fall",
-         "animation idle 2000",
-         "createware log",
+         "findobject=attrib:tree radius:10",
+         "walk=object",
+         "playsound=sound/atlanteans/saw sawing 230",
+         "animate=sawing 10000",
+         "playsound=sound/woodcutting tree-falling 130",
+         "callobject=fall",
+         "animate=idle 2000",
+         "createware=log",
          "return"
       }
    },
