@@ -2,7 +2,7 @@ dirname = path.dirname(__file__)
 
 animations = {
    idle = {
-      pictures = path.list_files(dirname .. "elk_idle_??.png"),
+      pictures = path.list_files(dirname .. "idle_??.png"),
       hotspot = { 15, 27 },
       fps = 20,
       sound_effect = {
@@ -12,11 +12,13 @@ animations = {
       },
    },
 }
-add_walking_animations(animations, dirname, "elk_walk", {21, 34}, 20)
+
+add_walking_animations(animations, "walk", dirname, "walk", {21, 34}, 20)
 
 world:new_critter_type{
    name = "elk",
    descname = _ "Elk",
+   editor_category = "critters_herbivores",
    attributes = { "eatable" },
    programs = {
       remove = { "remove" },
